#
# spec file for package embree
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2019-2022 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libembree3

Name:           embree
Version:        3.13.5
Release:        2.8
Summary:        Ray Tracing Kernels
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/embree/embree
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  ispc
BuildRequires:  memory-constraints
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  pkgconfig(glfw3)
# SSE2 resp. NEON is required: https://github.com/embree/embree#supported-platforms
ExclusiveArch:  x86_64 aarch64

%description
Intel Embree is a collection of ray tracing kernels originally developed
at Intel. The target users of Intel Embree are graphics application engineers
who want to improve the performance of their photo-realistic rendering
application by leveraging Embree's ray tracing kernels.

%package devel
Summary:        Development files for embree
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Obsoletes:      %{name}-devel-static <= %{version}

%description devel
This package contains the C++ header and CMake config files.

%package -n %{libname}
Summary:        Shared library providing Embree raytracing kernels
Group:          System/Libraries

%description -n %{libname}
Embree is a collection of ray tracing kernels.

This package contains the shared library.

%prep
%autosetup -p1

%build
%limit_build -m 1700
%ifarch aarch64
# https://github.com/embree/embree/issues/410
%global optflags %{optflags} -flax-vector-conversions
%endif
%cmake \
    -DEMBREE_IGNORE_CMAKE_CXX_FLAGS=OFF \
    -DEMBREE_STATIC_LIB=OFF \
    -DEMBREE_LIB_INSTALL_DIR=%{_libdir} \
    -DEMBREE_ISPC_SUPPORT=ON \
    -DEMBREE_TASKING_SYSTEM=INTERNAL \
    -DEMBREE_RAY_MASK=ON \
    -DEMBREE_FILTER_FUNCTION=ON \
    -DEMBREE_BACKFACE_CULLING=OFF \
%ifarch x86_64
    -DEMBREE_MAX_ISA=AVX2 \
%endif
%ifarch aarch64
    -DEMBREE_ARM=ON \
%endif
    -DEMBREE_TUTORIALS=OFF

%cmake_build

%install
%cmake_install
rm -r %{buildroot}%{_mandir}
rm -r %{buildroot}/usr/share/doc

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{_includedir}/embree3
%{_libdir}/cmake/%{name}-%{version}
%{_libdir}/*.so

%changelog
* Thu Nov  3 2022 Hans-Peter Jansen <hpj@urpla.net>
- Obsolete the -devel-static package
* Wed Nov  2 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Build embree as shared library, blender no longer requires a
  static library build.
- Reduce memory constraints, use limit_build to avoid build
  failures due to OOM.
- Fix build on ARM (gh#embree/embree#383, gh#embree/embree#410)
* Tue Oct 25 2022 Hans-Peter Jansen <hpj@urpla.net>
- Remove the cmake config tweaking
* Sat Oct 22 2022 hpj@urpla.net
- Update to version 3.13.5:
  * regenerated documentation
  * setting version to v3.13.5
  * ci: add github actions workflows
  * FastAllocator: fix the false sharing in SpinLock array
  * Fixed spatial splitting for non-planar quads.
  * no longer automatically starting thread nor setting affinity
  * disabling thread ID affinity re-mapping as it causes issues inside LXC containers
  * TBB: Stop task_scheduler_observer when TaskScheduler is destroyed
  * Improved self intersection avoidance for RTC_GEOMETRY_TYPE_DISC_POINT geometry type.
  * Fix compilation issues on macOS 12.5 and Apple clang version 13.1.6
- Update to version 3.13.4:
  * Using 8-wide BVH and double pumped NEON instructions on Apple M1 gives 8%% performance boost.
  * Fixed binning related crash in SAH BVH builder.
  * Added EMBREE_TBB_COMPONENT cmake option to define the component/library name of Intel® TBB (default: tbb).
  * Embree supports now Intel® oneAPI DPC++/C++ Compiler 2022.0.0
- Switch to _service based package source
- Use simd compiler ispc
* Sat Oct 22 2022 Hans-Peter Jansen <hpj@urpla.net>
- Fix cmake devel config to reflect reality
* Tue Apr 26 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints for aarch64
* Sun Apr 24 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to version v3.13.3
  * Invalid multi segment motion blurred normal oriented curves
    are properly excluded from BVH build.
  * Fixing issue with normal oriented curve construction when
    center curve curvature is very large.
  * Due to this change normal oriented curve shape changes
    slightly.
  * Fixed crash caused by disabling a geometry and then detaching
    it from the scene.
  * Bugfix in emulated ray packet intersection when
    EMBREE_RAY_PACKETS is turned off.
  * Bugfix for linear quaternion interpolation fallback.
  * Fixed issues with spaces in path to Embree build folder.
  * Some fixes to compile Embree in SSE mode using WebAssembly.
  * Bugfix for occlusion rays with grids and ray packets.
  * We do no longer provide installers for Windows and macOS,
    please use the ZIP files instead.
  * Upgrading to Intel® ISPC 1.17.0 for release build.
  * Upgrading to Intel® oneTBB 2021.5.0 for release build.
* Tue Nov 23 2021 Ben Greiner <code@bnavigator.de>
- Update to version 3.13.2
  * Avoiding spatial split positions that are slightly out of
    geometry bounds.
  * Introduced rtcGetGeometryThreadSafe function, which is a thread
    safe version of rtcGetGeometry.
  * Using more accurate rcp implementation.
  * Bugfix to rare corner case of high quality BVH builder.
- Embree 3.13.1
  * Added support for ISPC+ARM.
  * Releases upgrade to TBB 2021.3.0 and ISPC 1.16.1
- Use internal tasking instead of TBB
  * gh#embree/embree#348
  * boo#1192994
* Tue May 25 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.13.0
  * Added support for aarch64 cpu architecture.
  * RTC_SUBDIVISION_MODE_NO_BOUNDARY now works properly for
    non-manifold edges.
  * Embree no longer reads the .embree3 config files, thus all
    configuration has to get passed through the config string to
    rtcNewDevice.
  * Releases upgrade to TBB 2021.2.0 and ISPC 1.15.0
* Sun Apr 25 2021 Wang Jun <jgwang@suse.com>
- update to version 3.12.1
  * Fixed wrong uv and Ng for grid intersector in robust mode for AVX.
  * Removed optimizations for Knights Landing.
  * Upgrading release builds to use oneTBB 2021.1.1
* Thu Oct 15 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 3.12.1
  + Changed default frequency level to SIMD128 for Skylake, Cannon
    Lake, Comet Lake and Tiger Lake CPUs. This change typically
    improves performance for renderers that just use SSE by
    maintaining higher CPU frequencies. In case your renderer is
    AVX optimized you can get higher ray tracing performance
    by configuring the frequency level to simd256 through passing
    frequency_level=simd256 to rtcNewDevice.
* Fri Sep 25 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 3.12.0
  + Added linear cone curve geometry support. In this mode a real
    geometric surface for curves
  + with linear basis is rendered using capped cones. They are
    discontinuous at edge boundaries.
  + Enabled fast two level builder for instances when low quality
    build is requested.
  + Bugfix for BVH build when geometries got disabled.
  + Added EMBREE_BACKFACE_CULLING_CURVES cmake option. This allows
    for a cheaper round
  + linear curve intersection when correct internal tracking and
    back hits are not required.
  + The new cmake option defaults to OFF.
  + User geometries with invalid bounds with lower>upper in some
    dimension will be ignored.
  + Increased robustness for grid interpolation code and fixed
    returned out of range u/v
  + coordinates for grid primitive.
  + Fixed handling of motion blur time range for sphere, discs, and
    oriented disc geometries.
  + Fixed missing model data in releases.
  + Ensure compatibility to newer versions of oneTBB.
  + Motion blur BVH nodes no longer store NaN values.
* Tue Sep  1 2020 Hans-Peter Jansen <hpj@urpla.net>
- raise limits to 24G, since this version uses up to 22,6G on TW
  for build (16,7G on 15.2)
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memory limit as the build is dominated by 2 huge gas runs.
* Thu Jul  9 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 3.11.0
  + Round linear curves now automatically check for the existence
    of left and right
  + connected segments if the flags buffer is empty. Left segments
    exist if the
  + segment(id-1) + 1 == segment(id) and similarly for right
    segments.
  + Implemented the min-width feature for curves and points, which
    allows to increase the
  + radius in a distance dependent way, such that the curve or
    points thickness is n pixels wide.
  + Round linear curves are closed now also at their start.
  + Embree no longer supports Visual Studio 2013 starting with this
    release.
  + Bugfix in subdivision tessellation level assignment for non-
    quad base primitives
  + Small meshes are directly added to top level build phase of
    two-level builder to reduce memory consumption.
  + Enabled fast two level builder for user geometries when low
    quality build is requested.
- update to version 3.10.0
  + Added EMBREE_COMPACT_POLYS CMake option which enables double
    indexed triangle and quad
  + leaves to reduce memory consumption in compact mode by an
    additional 40%% at about
  + 15%% performance impact. This new mode is disabled by default.
  + Compile fix for oneTBB 2021.1-beta05
  + Releases upgrade to TBB 2020.2
  + Compile fix for ISPC v1.13.0
  + Adding RPATH to libembree.so in releases
  + Increased required CMake version to 3.1.0
  + Made instID member for array of pointers ray stream layout
    optional again.
- update to version 3.9.0
  + Added round linear curve geometry support. In this mode a real
    geometric surface for curves
  + with linear basis is rendered using capped cones with spherical
    filling between
  + the curve segments.
  + Added rtcGetSceneDevice API function, that returns the device a
    scene got created in.
  + Improved performance of round curve rendering by up to 1.8x.
  + Bugfix to sphere intersection filter invokation for back hit.
  + Fixed wrong assertion that triggered for invalid curves which
    anyway get filtered out.
  + RelWithDebInfo mode no longer enables assertions.
  + Fixed an issue in FindTBB.cmake that caused compile error with
    Debug build under Linux.
  + Embree releases no longer provide RPMs for Linux. Please use
    the RPMs coming with the package
  + manager of your Linux distribution.
* Wed Feb  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 3.8.0
  + New Features:
  * Added collision detection support for user geometries (see
    rtcCollide API function)
  * Passing geomID to user geometry callbacks.
  + Fixed Issues:
  * Bugfix in AVX512VL codepath for rtcIntersect1
  * For sphere geometries the intersection filter gets now
    invoked for front and back hit.
  * Fixed some bugs for quaternion motion blur.
  * RTCIntersectContext always non-const in Embree API
  * Made RTCHit aligned to 16 bytes in Embree API
- update to version 3.7.0
  + Added quaternion motion blur for correct interpolation of
    rotational transformations.
  + Fixed wrong bounding calculations when a motion blurred
    instance did instantiate a motion blurred scene.
  + In robust mode the depth test consistently uses tnear <= t <=
    tfar now in order to robustly continue traversal at a previous
    hit point in a way that guarentees reaching all hits, even hits
    at the same place.
  + Fixed depth test in robust mode to be precise at tnear and
    tfar.
  + Added next_hit tutorial to demonstrate robustly collecting all
    hits along a ray using multiple ray queries.
  + Implemented robust mode for curves. This has a small
    performance impact but fixes bounding problems with flat
    curves.
  + Improved quality of motion blur BVH by using linear bounds
    during binning.
  + Implemented issue with motion blur builder where number of time
    segments for SAH heuristic were counted wrong due to some
    numerical issues.
  + Fixed an accuracy issue with rendering very short fat curves.
  + rtcCommitScene can now get called during rendering from
    multiple threads to lazily build geometry. When TBB is used
    this causes a much lower overhead than using
    rtcJoinCommitScene.
  + Geometries can now get attached to multiple scenes at the same
    time, which simplifies mapping general scene graphs to API.
  + Updated to TBB 2019.9 for release builds.
  + Fixed a bug in the BVH builder for Grid geometries.
  + Added macOS Catalina support to Embree releases.
* Fri Oct 11 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.1
  Added Catmull-Rom curve types.
  Added support for multi-level instancing.
  Added support for point queries.
  Fixed a bug preventing normal oriented curves being used unless timesteps were specified.
  Fixed bug in external BVH builder when configured for dynamic build.
  Added support for new config flag "user_threads=N" to device initialization
  which sets the number of threads used by TBB but created by the user.
  Fixed automatic vertex buffer padding when using rtcSetNewGeometry API function.
* Mon Sep  9 2019 Jan Engelhardt <jengelh@inai.de>
- Trim marketing from description.
* Sun Sep  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Relax _constraints, and use memory-constraints/limit_build instead
- Disable building for every arch but x86_64, as embree strictly requires
  at least SSE2.
- Use FAT LTO objects in order to provide proper static library.
- Use tbb-devel BuildRequires instead of cmake(TBB), the latter is not
  available in Leap 15.x
* Mon Jul 15 2019 Hans-Peter Jansen <hpj@urpla.net>
- version 3.5.2: initial build
